#
# spec file for package python-Paste
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without tests

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-Paste
Version:        2.0.3
Release:        bp153.1.22
Url:            http://pythonpaste.org
Summary:        Tools for using a Web Server Gateway Interface stack
License:        MIT
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/P/Paste/Paste-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six > 1.4.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# Documentation build requirements:
BuildRequires:  python3-Sphinx
# Test build requirements:
BuildRequires:  %{python_module nose}
Suggests:       python-flup
Requires:       python-six > 1.4.0
%ifpython2
Suggests:       python-python-openid
Provides:       %{oldpython}-paste = %{version}
Obsoletes:      %{oldpython}-paste < %{version}
%endif
%ifpython3
Suggests:       python3-python3-openid
%endif
BuildArch:      noarch
%python_subpackages

%description
These provide several pieces of "middleware" (or filters) that can be nested
to build web applications.  Each piece of middleware uses the WSGI (PEP 333)
interface, and should be compatible with other middleware based on those
interfaces.

%prep
%setup -q -n Paste-%{version}
# remove test requiring internet access
rm tests/test_proxy.py
# remove .orig files (see https://bitbucket.org/ianb/paste/issues/11/pypi-tarball-of-version-202-contains-orig)
rm paste/urlmap.py.orig
rm paste/httpserver.py.orig
rm paste/util/template.py.orig

%build
%python_build
python3 setup.py build_sphinx && rm build/sphinx/html/.buildinfo

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with tests}
%check
%python_exec setup.py -q test
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc docs/license.txt
%doc build/sphinx/html/
%{python_sitelib}/*

%changelog
* Wed Aug  9 2017 tbechtold@suse.com
- Remove unused BuildRequires
- Use Suggests for openid and flup. Both are optional deps
* Fri May  5 2017 toddrme2178@gmail.com
- Fix Provides/Obsoletes.
* Wed Apr 19 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Fri Jun  3 2016 tbechtold@suse.com
- update to 2.0.3:
  * prepare release 2.0.1
  * Added tag 2.0.1 for changeset a0ef0e57e057
  * set version to 2.0.2
  * Add tests/test_httpserver.py
  * Fix improper commas in request headers in wsgi_environ
  * tests/test_httpserver.py: Use `email` module instead of `mimetools`
  * tests/test_httpserver.py: Add test_environ_with_multiple_values
  * Make get all values of a header work on both Python 2 and 3
  * Make get_headers default to Python 3; fallback to Python 2
  * Make utility function private: _get_headers
  * Fix Python 3 issue in paste/fixture.py
  * test_wsgirequest_charset: Use UTF-8 instead of iso-8859-1
  * Replace cgi.parse_qsl w/ six.moves.urllib.parse.parse_sql
  * replace ``has_key`` method to ``in`` operator #9
  * Don't display invalid error message when socket in use
  * Update docs/news.txt for 2.0.2
  * Added tag 2.0.2 for changeset 53f5c2cd7f50
  * Python 3: App must always return binary type.
  * Python 3: Always encode params if passed as text types
  * Python 3: Don't mangle strangely encoded input
  * Python 3: Use the same python interpreter for CGI scripts.
  * Python 3: add workarounds for cgi.FieldStorage
  * Python 3: avoid spurious warnings
  * Python 3: dict.items() doesn't return a list anymore
  * Python 3: ignore exception details in doctests
  * Python 3: let html_quote() and url() always return the same type
  * Python 3: use compatible print syntax in example text
  * Change six requirement to >=1.4.0
  * tox.ini: Add py35 to envlist
  * Enable testing with pypy
  * tox.ini: Measure test coverage
  * paste.wsgilib.add_close: Add __next__ method
  * Add tests for `add_close` class
  * Uncomment/cleanup paste.wsgilib.app_close.__next__
  * Check paste.wsgilib.add_close._closed
  * Make add_close.next() leverage add_close.__next__()
  * Bump version to 2.0.3
  * Close branch 2.0.3
- Remove .orig files
* Sun Mar 13 2016 dmueller@suse.com
- add license.txt
* Fri May  8 2015 benoit.monin@gmx.fr
- update to version 2.0.1:
  * Fix setup.py for six dependency: move the six dependency from
    extras_require to install_requires
  * Port paste.proxy to Python 3
  * Fix paste.exceptions.serial_number_generator.hash_identifier()
    on Python 3
  * Fix paste.util.threadedprint.uninstall()
  * Add README.rst file
- additional changes from version 2.0:
  * Experimental Python 3 support
  * paste now requires the six module
  * Drop support of Python 2.5 and older
  * Fixed egg:Paste#cgi
  * In paste.httpserver: give a 100 Continue response even when the
    server has been configured as an HTTP/1.0 server
  * Fixed parsing of paths beginning with multiple forward slashes
  * Add tox.ini to run tests with tox on Python 2.6, 2.7 and 3.4
- add python-six as dependency
- add python-flup, python-nose and python-python-openid as test
  dependencies
- remove test requiring internet access: test_proxy.py
- reenable the tests
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Thu Nov 22 2012 saschpe@suse.de
- Require python-python-openid instead of non-existing python-openid
- Build HTML documentation
* Wed Jun 22 2011 saschpe@suse.de
- Initial version, obsoletes 'python-paste'
